@@ -23,4 +23,4 @@ class SVSync(SVSyncBase):
         preSyncPrefix, preDataPrefix = groupPrefix + [Component.from_str("sync")], nid + groupPrefix + [Component.from_str("data")]
         super().__init__(app, preSyncPrefix, preDataPrefix, groupPrefix, nid, updateCallback, storage, securityOptions)
     def getDataName(self, nid:Name, seqno:int) -> Name:
-        return ( nid + self.groupPrefix + [Component.from_str("data")] + Name.from_str(str(seqno)) )
\ No newline at end of file
+        return ( nid + self.groupPrefix + [Component.from_str("data")] + [Component.from_str(str(seqno))] )
\ No newline at end of file
